Zprávy | OiRA

Témata

# Zprávy

Zprávu můžete využít k:

- předložení důkazů orgánům dohledu,
- předání informací dotčeným osobám (pracovníkům, zástupcům pro bezpečnost, zaměstnavatelům, odborníkům v oblasti bezpečnosti a ochrany zdraví při práci atd.),
- sledování a posuzování toho, zda byla zavedena nezbytná opatření,
- zaznamenávání veškerých revizí, pokud se změní okolnosti (nové stroje/pracovníci, nebo v důsledku zjištění plynoucích z vyšetřování nehod atd.).

Zprávu můžete uložit na svém počítači a vytisknout. Můžete ji rovněž upravit nebo přidat další informace. Upozorňujeme, že jakékoli změny provedené ve zprávě, kterou jste si stáhli, NEBUDOU v nástroji OiRA uloženy.

## Výběr zprávy

Pro různé účely jsou k dispozici různé druhy zpráv. Výběr zpráv, které jsou k dispozici pro konkrétní nástroje, závisí na rozhodnutích přijatých národním partnerem/vývojářem nástroje OiRA.

Dostupné zprávy.

### Úplná zpráva

Formát: Word / Office Open XML (.docx). Po stažení ji můžete upravovat.

Obsahuje: veškeré informace a vstupy, které jste zadali během procesu hodnocení rizik.

Použití: k předložení důkazů o hodnocení rizik orgánům dohledu (např. inspektorátu práce).

### Akční plán

Formát: Excel / Office Open XML (.xlsx). Po stažení jej můžete upravovat

Obsahuje: informace o všech opatřeních, která jste se rozhodli zavést.

Použití:

- k aktivnímu sledování provádění opatření, která jste si vybrali,
- k řešení problémů/rizik na pracovišti (konkrétní úkoly, odbornost, povinnosti, lhůty).

### Přehled rizik

Formát: PDF (.pdf) Po stažení jej nemůžete upravovat.

Obsahuje: přehled zjištěných rizik

Použití:

- k získání rychlého přehledu o stavu rizik na vašem pracovišti,
- k předání informací dotčeným osobám,
- ke sledování, zda jsou rizika/opatření řádně řešena.

### Přehled opatření

Formát: PDF (.pdf) Po stažení jej nemůžete upravovat.

Obsahuje: rychlý přehled opatření, která mají být provedena.

Použití:

- k získání rychlého přehledu o stavu opatření, která jste se rozhodli provést,
- k předání informací dotčeným osobám,
- ke sledování, zda jsou rizika/opatření řádně řešena.

Scroll to top Load toolbar…
Back

## 4-reports.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More